"use strict";
exports.__esModule = true;
var jscodeshift = require("jscodeshift");
var explicit_return_to_implicit_1 = require("../explicit-return-to-implicit");
var range = require("../../range");
var test_utils_1 = require("./test-utils");
var buildEditResponse = test_utils_1.createBuildFunction(explicit_return_to_implicit_1["default"]);
describe('javascript', function () {
    it('simple', function () {
        var source = '() => { return test() }';
        var r = buildEditResponse(source, range.create(1, 6, 1, 6));
        expect(r).toEqual({
            newText: 'test()',
            range: { end: { column: 23, line: 1 }, start: { column: 6, line: 1 } },
            title: 'Use implicit return'
        });
    });
    it('do not work on empty return', function () {
        var source = '() => { return }';
        var api = jscodeshift.withParser('babylon');
        var params = {
            j: api,
            ast: api(source),
            selection: range.create(1, 6, 1, 6),
            logger: console
        };
        var action = explicit_return_to_implicit_1["default"].suggestCodeAction(params);
        expect(action).toEqual(null);
    });
});
