"use strict";
exports.__esModule = true;
var require_to_import_1 = require("../require-to-import");
var range = require("../../range");
var test_utils_1 = require("./test-utils");
var buildEditResponse = test_utils_1.createBuildFunction(require_to_import_1["default"]);
describe('javascript', function () {
    it('named require', function () {
        var source = "const a = require('b')";
        var r = buildEditResponse(source, range.create(1, 15, 1, 15));
        expect(r).toEqual({
            newText: 'import a from "b";',
            range: { end: { column: 22, line: 1 }, start: { column: 0, line: 1 } },
            title: 'Convert require to ES import'
        });
    });
    it('cursor before require', function () {
        var source = "const a = require('b')";
        var r = buildEditResponse(source, range.create(1, 10, 1, 10));
        expect(r).toEqual({
            newText: 'import a from "b";',
            range: { end: { column: 22, line: 1 }, start: { column: 0, line: 1 } },
            title: 'Convert require to ES import'
        });
    });
    it('unnamed require', function () {
        var source = "require('b')";
        var r = buildEditResponse(source, range.create(1, 4, 1, 4));
        expect(r).toEqual({
            newText: 'import "b";',
            range: { end: { column: 12, line: 1 }, start: { column: 0, line: 1 } },
            title: 'Convert require to ES import'
        });
    });
});
describe('typescript', function () {
    it('named require', function () {
        var source = "const a = require('b')";
        var r = buildEditResponse(source, range.create(1, 15, 1, 15), 'ts');
        expect(r).toEqual({
            newText: 'import a from "b";',
            range: { end: { column: 22, line: 1 }, start: { column: 0, line: 1 } },
            title: 'Convert require to ES import'
        });
    });
    it('named require with type', function () {
        var source = "const a:number = require('b')";
        var r = buildEditResponse(source, range.create(1, 19, 1, 19), 'ts');
        expect(r).toEqual({
            newText: 'import a from "b";',
            range: { end: { column: 29, line: 1 }, start: { column: 0, line: 1 } },
            title: 'Convert require to ES import'
        });
    });
});
describe('flow', function () {
    it('named require', function () {
        var source = "const a = require('b')";
        var r = buildEditResponse(source, range.create(1, 15, 1, 15), 'flow');
        expect(r).toEqual({
            newText: 'import a from "b";',
            range: { end: { column: 22, line: 1 }, start: { column: 0, line: 1 } },
            title: 'Convert require to ES import'
        });
    });
    it('named require with type', function () {
        var source = "const a:number = require('b')";
        var r = buildEditResponse(source, range.create(1, 19, 1, 19), 'flow');
        expect(r).toEqual({
            newText: 'import a from "b";',
            range: { end: { column: 29, line: 1 }, start: { column: 0, line: 1 } },
            title: 'Convert require to ES import'
        });
    });
});
